GPSDataT

Struct GPSDataT 

#[repr(C)]
pub struct GPSDataT {
Show 17 fields pub set: GPSMaskT, pub online: TimestampT, pub gps_fd: SocketT, pub fix: GPSFixT, pub separation: c_double, pub status: c_int, pub satellites_used: c_int, pub dop: DopT, pub epe: c_double, pub skyview_time: TimestampT, pub satellites_visible: c_int, pub skyview: [SatelliteT; 72], pub dev: DevconfigT, pub policy: PolicyT, pub devices: Devices, pub union_never_reported: [c_int; 1418], pub privdata: *mut c_void,
}

Fields

set: GPSMaskT

has field been set since this was last cleared?

online: TimestampT

NZ if GPS is on line, 0 if not.

Note: gpsd clears this time when sentences fail to show up within the GPS’s normal send cycle time. If the host-to-GPS link is lossy enough to drop entire sentences, this field will be prone to false zero values.

gps_fd: SocketTfix: GPSFixT

socket or file descriptor to GPS accumulated PVT data

separation: c_double

this should move to the per-driver structure

status: c_int

Geoidal separation, MSL - WGS84 (Meters) GPS status – always valid

satellites_used: c_int

Do we have a fix? precision of fix – valid if satellites_used > 0

dop: DopT

Number of satellites used in solution

epe: c_double

redundant with the estimate elements in the fix structure

skyview_time: TimestampT

spherical position error, 95% confidence (meters) satellite status – valid when satellites_visible > 0

satellites_visible: c_int

skyview timestamp

of satellites in view

skyview: [SatelliteT; 72]dev: DevconfigTpolicy: PolicyT

device that shipped last update

devices: Devices

our listening policy

union_never_reported: [c_int; 1418]

Private data rtcm3_t largest in union -> sizeof 5672 = 4*1418

privdata: *mut c_void

Private data - client code must not set this